@@ -640,6 +640,7 @@ namespace IPod {
         Misc = 100,
         AlbumListAlbum = 200,
         AlbumListArtist = 201,
+        AlbumListTitle = 202,
         AlbumListPodcastUrl = 203
     }
 
@@ -685,13 +686,14 @@ namespace IPod {
             Type = (DetailType) ToInt32 (body, 0);
 
             if ((int) Type > 50 && Type != DetailType.Misc && Type != DetailType.LibraryIndex &&
-                Type != DetailType.AlbumListArtist && Type != DetailType.AlbumListAlbum && Type != DetailType.AlbumListPodcastUrl)
+                Type != DetailType.AlbumListArtist && Type != DetailType.AlbumListAlbum &&
+                Type != DetailType.AlbumListPodcastUrl && Type != DetailType.AlbumListTitle)
                 throw new DatabaseReadException ("Unsupported detail type: " + Type);
 
             unknownOne = ToInt32 (body, 4);
             unknownTwo = ToInt32 (body, 8);
             
-            if ((int) Type < 50 || Type == DetailType.AlbumListArtist || Type == DetailType.AlbumListAlbum || Type == DetailType.AlbumListPodcastUrl) {
+            if ((int) Type < 50 || (int) Type >= 200) {
                 if (Type == DetailType.PodcastUrl ||
                     Type == DetailType.PodcastUrl2) {
 
@@ -708,7 +710,7 @@ namespace IPod {
                     int strlen = 0;
                     //int strenc = 0;
             
-                    if ((int) Type < 50 || Type == DetailType.AlbumListArtist || Type == DetailType.AlbumListAlbum || Type == DetailType.AlbumListPodcastUrl) {
+                    if ((int) Type < 50 || (int) Type >= 200) {
                         // 'string' mhods       
                         strlen = ToInt32 (body, 16);
                         //strenc = ToInt32 (body, 20); // 0 == UTF16, 1 == UTF8
@@ -758,8 +760,7 @@ namespace IPod {
 
             byte[] valbytes = null;
 
-            if ((int) Type < 50 || Type == DetailType.AlbumListArtist || Type == DetailType.AlbumListAlbum ||
-                Type == DetailType.AlbumListPodcastUrl) {
+            if ((int) Type < 50 || (int) Type >= 200) {
                 if (Type == DetailType.PodcastUrl || Type == DetailType.PodcastUrl2) {
                     valbytes = Encoding.UTF8.GetBytes (Value);
                     writer.Write (24 + valbytes.Length);
@@ -786,8 +787,7 @@ namespace IPod {
             writer.Write (unknownOne);
             writer.Write (unknownTwo);
 
-            if ((int) Type < 50 || Type == DetailType.AlbumListArtist || Type == DetailType.AlbumListAlbum ||
-                Type == DetailType.AlbumListPodcastUrl) {
+            if ((int) Type < 50 || (int) Type >= 200) {
                 if (Type == DetailType.PodcastUrl || Type == DetailType.PodcastUrl2 ||
                     Type == DetailType.ChapterData) {
                     writer.Write (valbytes);
@@ -1161,49 +1161,37 @@ namespace IPod {
 
         public long NextDatabaseId = 1;
 
-        private List<TrackRecord> tracks = new List<TrackRecord> ();
+        private SortedList<int, TrackRecord> tracks = new SortedList<int, TrackRecord>();
 
         public IList<TrackRecord> Tracks {
-            get { return new ReadOnlyCollection<TrackRecord> (tracks); }
+            get { return new ReadOnlyCollection<TrackRecord>(tracks.Values); }
         }
 
-        public TrackListRecord (bool isbe) : base (isbe) {
+        public TrackListRecord(bool isbe) : base(isbe) {
             this.Name = "mhlt";
         }
 
-        public void Remove (int id) {
-            foreach (TrackRecord track in tracks) {
-                if (track.Id == id) {
-                    tracks.Remove (track);
-                    break;
-                }
-            }
+        public void Remove(int id) {
+            tracks.Remove(id);
         }
 
-        public void Add (TrackRecord track) {
-            tracks.Add (track);
+        public void Add(TrackRecord track) {
+            tracks.Add(track.Id, track);
         }
 
-        public IEnumerator GetEnumerator () {
-            return tracks.GetEnumerator ();
+        public IEnumerator GetEnumerator() {
+            return ((IEnumerable)tracks.Values).GetEnumerator();
         }
 
-        public TrackRecord LookupTrack (int id) {
-            foreach (TrackRecord record in tracks) {
-                if (record.Id == id)
-                    return record;
-            }
+        public TrackRecord LookupTrack(int id) {
+            if (tracks.ContainsKey(id))
+                return tracks[id];
 
             return null;
         }
 
-        public int IndexOf (int id) {
-            for (int i = 0; i < tracks.Count; i++) {
-                if ((tracks[i] as TrackRecord).Id == id)
-                    return i;
-            }
-
-            return -1;
+        public int IndexOf(int id) {
+            return tracks.IndexOfKey(id);
         }
         
         public override void Read (DatabaseRecord db, BinaryReader reader) {
@@ -1224,7 +1212,7 @@ namespace IPod {
                     NextDatabaseId = rec.DatabaseId + 1;
                 }
                 
-                tracks.Add (rec);
+                tracks.Add(rec.Id, rec);
             }
         }
 
@@ -1233,7 +1221,7 @@ namespace IPod {
             MemoryStream stream = new MemoryStream ();
             BinaryWriter childWriter = new EndianBinaryWriter (stream, IsBE);
 
-            foreach (TrackRecord rec in tracks) {
+            foreach (TrackRecord rec in tracks.Values) {
                 rec.Save (db, childWriter);
             }
 
